@@ -35,7 +35,7 @@ Usage::
     list_shared_report_groups_paginator: ListSharedReportGroupsPaginator = client.get_paginator("list_shared_report_groups")
     ```
 """
-from mypy_boto3_codebuild.client import CodeBuildClient, CodeBuildClient as Client
+from mypy_boto3_codebuild.client import CodeBuildClient
 from mypy_boto3_codebuild.paginator import (
     DescribeTestCasesPaginator,
     ListBuildsForProjectPaginator,
@@ -48,6 +48,8 @@ from mypy_boto3_codebuild.paginator import (
     ListSharedReportGroupsPaginator,
 )
 
+Client = CodeBuildClient
+
 
 __all__ = (
     "Client",
